import logging
import structlog

class StructlogRawMessageHandler(logging.StreamHandler):
    level = logging.DEBUG
    filters = []
    lock = None
    _name = "StructlogRawMessageHandler"

    def __init__(self):
        self._log = structlog.get_logger()

    def emit(self, record):
        self._log.log(record.levelno, record.msg, name=record.name)



import threading

local = threading.local()

DEFAULT_HEADER_VALUE = "none"
LOG_LABEL_REQUEST_SETTING = 'LOG_LABEL_REQUEST_SETTING'
LOG_LABEL_LOGGER_NAME = 'LOG_LABEL_LOGGER_NAME'
MAX_REQUEST_RESPONSE_SIZE = 'MAX_REQUEST_RESPONSE_SIZE'
